### Duke.ai Lib (*dukeai_lib*)

Latest Release: 2023-07-25

Latest Version: 0.1.1

---

*The dukeai_lib PIP package repository; Contains base functions that are used across multiple internal backend projects making it easier to maintain via a centralized codebase, and enabling retroactive updates to core functions.*

---
**Modules**

- tools

   - gen_random_sha()

- application

   - check_access()
   - api_response()

- utilities

   - DecimalEncoder(class)

---

**Usage**

pip install dukeai_lib

*and subsequently...*

import dukeai_lib